@@ -43,6 +43,12 @@ return ['routes' => [
 		'url' => '/notes/undo',
 		'verb' => 'POST',
 	],
+	[
+		'name' => 'notes#autotitle',
+		'url' => '/notes/{id}/autotitle',
+		'verb' => 'PUT',
+		'requirements' => ['id' => '\d+'],
+	],
 	[
 		'name' => 'notes#update',
 		'url' => '/notes/{id}',
