@@ -1,19 +1,19 @@
 OC.L10N.register(
     "notes",
     {
-    "Notes" : "Notas",
     "The last viewed note cannot be accessed. " : "No se puede acceder a la última nota consultada. ",
-    "New note" : "Nota nueva",
-    "Encryption Error" : "Error de encripción",
     "Error" : "Error",
-    "There are unsaved notes. Leaving the page will discard all changes!" : "Hay notas sin salvar. ¡Al salir de la página perderá todos los cambios!",
+    "New note" : "Nota nueva",
+    "Notes" : "Notas",
     "Settings" : "Configuraciones ",
+    "There are unsaved notes. Leaving the page will discard all changes!" : "Hay notas sin salvar. ¡Al salir de la página perderá todos los cambios!",
     "All notes" : "Todas las notas",
     "Categories" : "Categorías",
     "Today" : "Hoy",
     "Yesterday" : "Ayer",
     "This week" : "Esta semana",
     "This month" : "Este mes",
+    "Rename" : "Renombrar",
     "Delete note" : "Borrar nota",
     "Remove from favorites" : "Eliminar de favoritos",
     "Add to favorites" : "Agregar a tus favoritos",
