@@ -5,17 +5,24 @@ OC.L10N.register(
     "New note" : "Нова нотатка",
     "Notes" : "Нотатки",
     "Settings" : "Налаштування",
+    "All notes" : "Усі нотатки",
     "Categories" : "Категорії",
     "Loading …" : "Завантаження...",
     "Today" : "Сьогодні",
     "Yesterday" : "Вчора",
+    "This week" : "Цього тижня",
+    "Last week" : "Минулого тижня",
+    "This month" : "Цього місяця",
+    "Last month" : "Минулого місяця",
     "Rename" : "Перейменувати",
     "Delete note" : "Вилучити нотатку",
     "Remove from favorites" : "Вилучено з улюбленого",
     "Add to favorites" : "Додати до улюбленого",
     "Details" : "Деталі",
+    "Preview" : "Перегляд",
     "Edit" : "Редашувати",
     "Category" : "Категорія",
+    "Uncategorized" : "Некатегоризоване",
     "_%n word_::_%n words_" : ["%n слово","%n слів","%n слів","%n слів"],
     "Android app" : "Застосунок для Android",
     "iOS app" : "Застосунок для iOS"
