@@ -5,6 +5,7 @@ namespace OCA\Notes\Controller;
 use OCA\Notes\Service\NotesService;
 use OCA\Notes\Service\MetaService;
 use OCA\Notes\Service\SettingsService;
+use OCA\Notes\Service\NoteDoesNotExistException;
 
 use OCP\AppFramework\Controller;
 use OCP\IRequest;
@@ -78,17 +79,21 @@ class NotesController extends Controller {
 						return $note->getData([ 'content' ]);
 					}
 				}, $data['notes']);
-				if ($lastViewedNote) {
+				if ($lastViewedNote && !$pruneBefore) {
 					// check if note exists
 					try {
 						$this->notesService->get($userId, $lastViewedNote);
-					} catch (\Exception $ex) {
+					} catch (\Throwable $ex) {
+						if (!($ex instanceof NoteDoesNotExistException)) {
+							$this->helper->logException($ex);
+						}
 						$this->settings->deleteUserValue($userId, $this->appName, 'notesLastViewedNote');
 						$lastViewedNote = 0;
 						$errorMessage = $this->l10n->t('The last viewed note cannot be accessed. ').$ex->getMessage();
 					}
 				}
-			} catch (\Exception $e) {
+			} catch (\Throwable $e) {
+				$this->helper->logException($e);
 				$errorMessage = $this->l10n->t('The notes folder is not accessible: %s', $e->getMessage());
 			}
 
@@ -123,7 +128,11 @@ class NotesController extends Controller {
 				strval($id)
 			);
 
-			return $note->getData();
+			$result = $note->getData();
+			$etag = md5(json_encode($result));
+			return (new JSONResponse($result))
+				->setETag($etag)
+			;
 		});
 	}
 
@@ -182,14 +191,26 @@ class NotesController extends Controller {
 	/**
 	 * @NoAdminRequired
 	 */
-	public function update(int $id, string $content, bool $autotitle) : JSONResponse {
-		return $this->helper->handleErrorResponse(function () use ($id, $content, $autotitle) {
+	public function autotitle(int $id) : JSONResponse {
+		return $this->helper->handleErrorResponse(function () use ($id) {
+			$note = $this->notesService->get($this->helper->getUID(), $id);
+			$oldTitle = $note->getTitle();
+			$newTitle = $this->notesService->getTitleFromContent($note->getContent());
+			if ($oldTitle !== $newTitle) {
+				$note->setTitle($newTitle);
+			}
+			return $note->getTitle();
+		});
+	}
+
+
+	/**
+	 * @NoAdminRequired
+	 */
+	public function update(int $id, string $content) : JSONResponse {
+		return $this->helper->handleErrorResponse(function () use ($id, $content) {
 			$note = $this->notesService->get($this->helper->getUID(), $id);
 			$note->setContent($content);
-			if ($autotitle) {
-				$title = $this->notesService->getTitleFromContent($content);
-				$note->setTitle($title);
-			}
 			return $note->getData();
 		});
 	}
